@@ -55,8 +55,8 @@
 #' Takuya Yanagida \email{takuya.yanagida@@univie.ac.at}
 #'
 #' @seealso
-#' \code{\link{write.result}}, \code{\link{item.cfa}}, \code{\link{item.omega}},
-#' \code{\link{item.reverse}}, \code{\link{item.scores}}
+#' \code{\link{item.omega}}, \code{\link{item.cfa}}, \code{\link{item.invar}},
+#' \code{\link{item.reverse}}, \code{\link{item.scores}}, \code{\link{write.result}}
 #'
 #' @references
 #' Chalmers, R. P. (2018). On misconceptions and the limited usefulness of ordinal alpha.
@@ -486,7 +486,7 @@ item.alpha <- function(x, exclude = NULL, std = FALSE, ordered = FALSE, na.omit
                  args = list(exclude = exclude, std = std, ordered = ordered, na.omit = na.omit,
                              print = print, digits = digits, conf.level = conf.level, as.na = as.na,
                              check = check, output = output),
-                 result = list(alpha = alpha.x, descript = itemstat))
+                 result = list(alpha = alpha.x, itemstat = itemstat))
 
   class(object) <- "misty.object"
 
